@@ -28,6 +28,7 @@
 #include <QGridLayout>
 #include <QApplication>
 #include <QAbstractItemView>
+#include <QStyle>
 
 #include <KIconLoader>
 #include <KColorScheme>
@@ -51,7 +52,7 @@ public:
         tooltip(nullptr),
         view(nullptr),
         timer(nullptr),
-        delay(300)
+        delay(QApplication::style()->styleHint(QStyle::SH_ToolTip_WakeUpDelay))
         { }
 
     KToolTipWidget *tooltip;
